@@ -51,7 +51,7 @@ class FileLink:
 
     @property
     def quoted_full_file_name(self) -> str:
-        warnings.warn("'quoted_full_file_name' is deprecated, replace it with 'filename'", DeprecationWarning)
+        warnings.warn("'quoted_full_file_name' is deprecated, was removed", DeprecationWarning)
         return self.filename
 
     @property
